@@ -4,9 +4,9 @@
 This module defines classes for point defects
 """
 from __future__ import division
+
 import os
 import abc
-import re
 import json
 from bisect import bisect_left
 
@@ -20,7 +20,7 @@ from pymatgen.analysis.structure_analyzer import VoronoiCoordFinder, \
     RelaxationAnalyzer
 from pymatgen.analysis.structure_matcher import StructureMatcher
 from pymatgen.analysis.bond_valence import BVAnalyzer
-from pymatgen.core.periodic_table import Specie, Element
+from pymatgen.core.periodic_table import Specie
 
 file_dir = os.path.dirname(__file__)
 rad_file = os.path.join(file_dir, 'ionic_radii.json')
@@ -87,7 +87,7 @@ class ValenceIonicRadiusEvaluator:
             coord_no = int(round(coord_finder.get_coordination_number(i)))
             try:
                 tab_oxi_states = map(int, _ion_radii[el].keys())
-                tab_oxi_states.sort() 
+                tab_oxi_states.sort()
                 oxi_state = nearest_key(tab_oxi_states, oxi_state)
                 radius = _ion_radii[el][str(oxi_state)][str(coord_no)]
             except KeyError:
@@ -378,7 +378,6 @@ class Vacancy(Defect):
             sc = self.make_supercells_with_defects(um)[1:]
             rad_dict = self.struct_radii
             for i in range(len(sc)):
-                site_radi = rad_dict[self._defect_sites[i].specie.symbol]
                 vol, sa = get_void_volume_surfarea(sc[i], rad_dict)
                 self._vol.append(vol)
                 self._sa.append(sa)
@@ -498,7 +497,7 @@ class Interstitial(Defect):
     Subclass of Defect to generate interstitial sites
     """
 
-    def __init__(self, structure, valences, radii):
+    def __init__(self, structure, valences, radii, site_type='voronoi_vertex'):
         """
         Given a structure, generate symmetrically distinct interstitial sites.
 
@@ -507,6 +506,9 @@ class Interstitial(Defect):
             valences: Dictionary of oxidation states of elements in {
                 El:valence} form
             radii: Radii of elemnts in the structure
+            site_type: voronoi_vertex uses voronoi nodes
+                       voronoi_facecenter uses voronoi polyhedra face centers
+                       Default is voronoi_vertex
         """
 
         try:
@@ -515,21 +517,29 @@ class Interstitial(Defect):
         except:
             try:
                 bv = BVAnalyzer(symm_tol=0.0)
-                self._structure = bv.get_oxi_state_decorated_structure(structure)
+                self._structure = bv.get_oxi_state_decorated_structure(
+                        structure
+                        )
             except:
-                raise 
-        #self._structure = structure
+                raise
         self._valence_dict = valences
         self._rad_dict = radii
 
-        #Use Zeo++ to obtain the voronoi nodes. Apply symmetry reduction and
-        #the symmetry reduced voronoi nodes
-        #are possible candidates for interstitial sites
-        #try:
-        possible_interstitial_sites = symmetry_reduced_voronoi_nodes(
-                self._structure, self._rad_dict)
-        #except:
-        #    raise ValueError("Symmetry_reduced_voronoi_nodes failed")
+        """
+        Use Zeo++ to obtain the voronoi nodes. Apply symmetry reduction
+        and the symmetry reduced voronoi nodes are possible candidates
+        for interstitial sites.
+        """
+        vor_node_sites, vor_facecenter_sites = symmetry_reduced_voronoi_nodes(
+                self._structure, self._rad_dict
+                )
+
+        if site_type == 'voronoi_vertex':
+            possible_interstitial_sites = vor_node_sites
+        elif site_type == 'voronoi_facecenter':
+            possible_interstitial_sites = vor_facecenter_sites
+        else:
+            raise ValueError("Input site type not implemented")
 
         #Do futher processing on possibleInterstitialSites to obtain
         #interstitial sites
@@ -646,8 +656,6 @@ class Interstitial(Defect):
         coordinates.
         """
         distinct_radii = list(set(self._radii))
-        no_dstnt_radii = len(distinct_radii)
-        flag = [False] * no_dstnt_radii
         for rad in distinct_radii:
             ind = self._radii.index(rad)  # Index of first site with 'rad'
             for i in reversed(range(ind + 1, len(self._radii))):
@@ -777,8 +785,6 @@ class InterstitialAnalyzer:
             scale_mat = [[scd, 0, 0], [0, scd, 0], [0, 0, scd]]
             sc = self._inter.make_supercells_with_defects(scale_mat, self._el)
             blk_energy = get_energy_buckingham(sc[0])
-            no = len(sc[0].sites)
-            #print no
             for i in range(1, no_inter + 1):
                 inter_energy = get_energy_buckingham(
                     sc[i], keywords=inter_gulp_kw, valence_dict=val_dict
@@ -1252,14 +1258,6 @@ def symmetry_reduced_voronoi_nodes(structure, rad_dict):
     Returns:
         Symmetrically distinct voronoi nodes as pymatgen Strucutre
     """
-    vor_node_struct = get_voronoi_nodes(structure, rad_dict)
-    vor_symmetry_finder = SymmetryFinder(vor_node_struct, symprec=1e-1)
-    vor_symm_struct = vor_symmetry_finder.get_symmetrized_structure()
-    #print vor_symm_struct.lattice
-    #print vor_symm_struct.lattice.abc, vor_symm_struct.lattice.angles
-    #print vor_node_struct.lattice
-    #print vor_node_struct.lattice.abc, vor_node_struct.lattice.angles
-    equiv_sites_list = vor_symm_struct.equivalent_sites
 
     def add_closest_equiv_site(dist_sites, equiv_sites):
         if not dist_sites:
@@ -1276,16 +1274,25 @@ def symmetry_reduced_voronoi_nodes(structure, rad_dict):
             ind = avg_dists.index(min_avg_dist)
             dist_sites.append(equiv_sites[ind])
 
-    dist_sites = []
-    for equiv_sites in equiv_sites_list:
-        add_closest_equiv_site(dist_sites, equiv_sites)
+    vor_node_struct, vor_facecenter_struct  = get_voronoi_nodes(
+                    structure, rad_dict)
+    vor_node_symmetry_finder = SymmetryFinder(vor_node_struct, symprec=1e-1)
+    vor_node_symm_struct = vor_node_symmetry_finder.get_symmetrized_structure()
+    node_equiv_sites_list = vor_node_symm_struct.equivalent_sites
 
-    #lat = structure.lattice
-    #sp = [site.specie for site in sites]   # "X" because to Zeo++
-    #coords = [site.coords for site in sites]
-    #vor_node_radii = [site.properties['voronoi_radius'] for site in sites]
-    #vor_node_struct = Structure(lat, sp, coords,
-    #        coords_are_cartesian=True,
-    #        site_properties={'voronoi_radius':vor_node_radii}
-    #        )
-    return dist_sites
+    node_dist_sites = []
+    for equiv_sites in node_equiv_sites_list:
+        add_closest_equiv_site(node_dist_sites, equiv_sites)
+
+    vor_fc_symmetry_finder = SymmetryFinder(
+                    vor_facecenter_struct, symprec=1e-1)
+    vor_fc_symm_struct = vor_fc_symmetry_finder.get_symmetrized_structure()
+    facecenter_equiv_sites_list = vor_fc_symm_struct.equivalent_sites
+
+    facecenter_dist_sites = []
+    for equiv_sites in facecenter_equiv_sites_list:
+        add_closest_equiv_site(facecenter_dist_sites, equiv_sites)
+    if not facecenter_equiv_sites_list:     # Fix this so doesn't arise
+        facecenter_dist_sites = vor_facecenter_struct.sites
+
+    return node_dist_sites, facecenter_dist_sites
