@@ -17,6 +17,7 @@ __date__ = "December 10, 2012"
 
 import re
 import math
+import csv
 
 from pymatgen.core.periodic_table import Element
 from pymatgen.core.structure import Composition
@@ -41,102 +42,56 @@ class PourbaixEntry(MSONable):
     """
     def __init__(self, entry, correction=0.0, entry_id=None):
         if isinstance(entry, IonEntry):
-            self._entry = entry
-            self._conc = 1.0e-6
-            self._phase_type = "Ion"
-            self._charge = entry.composition.charge
+            self.entry = entry
+            self.conc = 1.0e-6
+            self.phase_type = "Ion"
+            self.charge = entry.composition.charge
         else:
-            self._entry = entry
-            self._conc = 1.0
-            self._phase_type = "Solid"
-            self._charge = 0.0
-        self._npH = None
-        self._nPhi = None
-        self._nH2O = None
-        self._nM = None
+            self.entry = entry
+            self.conc = 1.0
+            self.phase_type = "Solid"
+            self.charge = 0.0
         self.uncorrected_energy = entry.energy
         self.correction = correction
-        self._calc_coeff_terms()
-        self._name = self._entry.composition.reduced_formula
-        if self._phase_type == "Solid":
-            self._name += "(s)"
+        nH = 0
+        nO = 0
+        nM = 0
+        for elt in self.entry.composition.elements:
+            if elt == Element("H"):
+                nH = self.entry.composition[elt]
+            elif elt == Element("O"):
+                nO = self.entry.composition[elt]
+            else:
+                nM += self.entry.composition[elt]
+        self.nM = nM
+        self.npH = (nH - 2 * nO)
+        self.nH2O = nO
+        self.nPhi = (nH - 2 * nO - self.charge)
+        self.name = self.entry.composition.reduced_formula
+        if self.phase_type == "Solid":
+            self.name += "(s)"
         try:
             self.entry_id = entry.entry_id
         except AttributeError:
             self.entry_id = entry_id
 
-    @property
-    def _g0(self):
-        return self.energy
-
     @property
     def energy(self):
         return self.uncorrected_energy + self.correction
 
-    @property
-    def name(self):
-        """
-        Returns the entry's name
-        """
-        return self._name
-
-    def set_name(self, string):
-        """
-        Set name of entry
-
-        Args:
-            string: Input string
-        """
-        self._name = string
-
-    @property
-    def npH(self):
-        """
-        Returns value of npH, the coefficient of pH
-        """
-        return self._npH
-
-    @property
-    def nH2O(self):
-        """
-        Returns coefficient of Mu_H2O
-        """
-        return self._nH2O
-
-    @property
-    def nPhi(self):
-        """
-        Returns nPhi, the coefficient of Phi
-        """
-        return self._nPhi
-
     @property
     def g0(self):
         """
         Return g0 for the entry. Legacy function.
         """
-        return self._g0
-
-    @property
-    def conc(self):
-        """
-        Return concentration of the entry. Returns 1 if solid.
-        """
-        return self._conc
+        return self.energy
 
     @property
     def conc_term(self):
         """
         Returns the concentration contribution to the free energy.
         """
-        return self.normalization_factor * PREFAC * math.log10(self._conc)
-
-    @property
-    def phase_type(self):
-        """
-        Returns whether the entry is a solid/ion.
-        """
-        return self._phase_type
+        return self.normalization_factor * PREFAC * math.log10(self.conc)
 
     def g0_add(self, term):
         """
@@ -166,15 +121,15 @@ class PourbaixEntry(MSONable):
         """
         d = {"@module": self.__class__.__module__,
              "@class": self.__class__.__name__}
-        if isinstance(self._entry, IonEntry):
+        if isinstance(self.entry, IonEntry):
             d["entry type"] = "Ion"
         else:
             d["entry type"] = "Solid"
-        d["entry"] = self._entry.to_dict
-        d["pH factor"] = self._npH
-        d["voltage factor"] = self._nPhi
-        d["concentration"] = self._conc
-        d["H2O factor"] = self._nH2O
+        d["entry"] = self.entry.to_dict
+        d["pH factor"] = self.npH
+        d["voltage factor"] = self.nPhi
+        d["concentration"] = self.conc
+        d["H2O factor"] = self.nH2O
         d["energy"] = self.energy
         d["correction"] = self.correction
         d["entry_id"] = self.entry_id
@@ -194,31 +149,12 @@ class PourbaixEntry(MSONable):
         entry_id = d["entry_id"]
         return PourbaixEntry(entry, correction, entry_id)
 
-    def _calc_coeff_terms(self):
-        """
-        Calculates coefficients of pH, V, H2O
-        """
-        nH = 0
-        nO = 0
-        nM = 0
-        for elt in self._entry.composition.elements:
-            if elt == (Element("H")):
-                nH = self.entry.composition[elt]
-            elif elt == (Element("O")):
-                nO = self.entry.composition[elt]
-            else:
-                nM += self.entry.composition[elt]
-        self._nM = nM
-        self._npH = (nH - 2 * nO)
-        self._nH2O = nO
-        self._nPhi = (nH - 2 * nO - self._charge)
-
     @property
     def normalization_factor(self):
         """
         Normalize each entry by nM
         """
-        fact = 1.0 / self._nM
+        fact = 1.0 / self.nM
         return fact
 
     def scale(self, factor):
@@ -228,23 +164,15 @@ class PourbaixEntry(MSONable):
         Args:
             factor: Normalization factor
         """
-        self._npH *= factor
-        self._nPhi *= factor
-        self._nH2O *= factor
+        self.npH *= factor
+        self.nPhi *= factor
+        self.nH2O *= factor
         self.uncorrected_energy *= factor
         self.correction *= factor
-#        self._g0 *= factor
 
     def normalize(self, factor):
         self.scale(factor)
 
-    @property
-    def charge(self):
-        """
-        Returns charge of entry
-        """
-        return self._charge
-
     @property
     def composition(self):
         """
@@ -252,13 +180,6 @@ class PourbaixEntry(MSONable):
         """
         return self.entry.composition
 
-    @property
-    def entry(self):
-        """
-        Returns IonEntry/PDEntry object
-        """
-        return self._entry
-
     def reduced_entry(self):
         """
         Calculate reduction factor for composition, and reduce parameters by
@@ -266,7 +187,7 @@ class PourbaixEntry(MSONable):
         """
         reduction_factor = self.entry.composition.\
             get_reduced_composition_and_factor()[1]
-        self._nM /= reduction_factor
+        self.nM /= reduction_factor
         self.scale(1.0 / reduction_factor)
 
     @property
@@ -277,18 +198,9 @@ class PourbaixEntry(MSONable):
         return self.entry.composition.num_atoms\
             / self.entry.composition.get_reduced_composition_and_factor()[1]
 
-    def set_conc(self, conc):
-        """
-        Set concentration manually.
-
-        Args:
-            conc: Input concentration
-        """
-        self._conc = conc
-
     def __repr__(self):
         return "Pourbaix Entry : {} with energy = {:.4f}, npH = {}, nPhi = {},\
-             nH2O = {}".format(self._entry.composition, self.g0, self.npH,
+             nH2O = {}".format(self.entry.composition, self.g0, self.npH,
                                self.nPhi, self.nH2O)
 
     def __str__(self):
@@ -309,30 +221,30 @@ class MultiEntry(PourbaixEntry):
             weights: Weights associated with each entry. Default is None
         """
         if weights is None:
-            self._weights = [1.0] * len(entry_list)
+            self.weights = [1.0] * len(entry_list)
         else:
-            self._weights = weights
-        self._entrylist = entry_list
+            self.weights = weights
+        self.entrylist = entry_list
         self.correction = 0.0
         self.uncorrected_energy = 0.0
-        self._npH = 0.0
-        self._nPhi = 0.0
-        self._nH2O = 0.0
-        self._nM = 0.0
-        self._name = ""
+        self.npH = 0.0
+        self.nPhi = 0.0
+        self.nH2O = 0.0
+        self.nM = 0.0
+        self.name = ""
         self.entry_id = list()
         for i in xrange(len(entry_list)):
             entry = entry_list[i]
-            self.uncorrected_energy += self._weights[i] * \
+            self.uncorrected_energy += self.weights[i] * \
                 entry.uncorrected_energy
-            self.correction += self._weights[i] * entry.correction
-            self._npH += self._weights[i] * entry.npH
-            self._nPhi += self._weights[i] * entry.nPhi
-            self._nH2O += self._weights[i] * entry.nH2O
-            self._nM += self._weights[i] * entry._nM
-            self._name += entry.name + " + "
+            self.correction += self.weights[i] * entry.correction
+            self.npH += self.weights[i] * entry.npH
+            self.nPhi += self.weights[i] * entry.nPhi
+            self.nH2O += self.weights[i] * entry.nH2O
+            self.nM += self.weights[i] * entry.nM
+            self.name += entry.name + " + "
             self.entry_id.append(entry.entry_id)
-        self._name = self._name[:-3]
+        self.name = self.name[:-3]
 
     @property
     def normalization_factor(self):
@@ -340,8 +252,8 @@ class MultiEntry(PourbaixEntry):
         Normalize each entry by nM
         """
         norm_fac = 0.0
-        for i in xrange(len(self._entrylist)):
-            entry = self._entrylist[i]
+        for i in xrange(len(self.entrylist)):
+            entry = self.entrylist[i]
             for el in entry.composition.elements:
                 if (el == Element("O")) | (el == Element("H")):
                     continue
@@ -350,7 +262,7 @@ class MultiEntry(PourbaixEntry):
                         get_reduced_composition_and_factor()[1]
                 else:
                     red_fac = 1.0
-                norm_fac += self._weights[i] * entry.composition[el] / red_fac
+                norm_fac += self.weights[i] * entry.composition[el] / red_fac
         fact = 1.0 / norm_fac
         return fact
 
@@ -359,7 +271,7 @@ class MultiEntry(PourbaixEntry):
             "nPhi = {}, nH2O = {}".format(
             self.g0, self.npH, self.nPhi, self.nH2O)
         str += ", species: "
-        for entry in self._entrylist:
+        for entry in self.entrylist:
             str += entry.name + " + "
         return str[:-3]
 
@@ -369,15 +281,11 @@ class MultiEntry(PourbaixEntry):
     @property
     def conc_term(self):
         sum_conc = 0.0
-        for i in xrange(len(self._entrylist)):
-            entry = self._entrylist[i]
-            sum_conc += self._weights[i] * PREFAC * math.log10(entry.conc)
+        for i in xrange(len(self.entrylist)):
+            entry = self.entrylist[i]
+            sum_conc += self.weights[i] * PREFAC * math.log10(entry.conc)
         return sum_conc * self.normalization_factor
 
-    @property
-    def entrylist(self):
-        return self._entrylist
-
 
 class IonEntry(PDEntry):
     """
@@ -397,9 +305,9 @@ class IonEntry(PDEntry):
         set to some other string for display purposes.
     """
     def __init__(self, ion, energy, name=None):
-        self._energy = energy
-        self._composition = ion
-        self.name = name if name else self._composition.reduced_formula
+        self.energy = energy
+        self.composition = ion
+        self.name = name if name else self.composition.reduced_formula
 
     @classmethod
     def from_dict(cls, d):
@@ -413,29 +321,15 @@ class IonEntry(PDEntry):
         """
         Creates a dict of composition, energy, and ion name
         """
-        d = {"composition": self._composition.to_dict, "energy": self._energy}
+        d = {"composition": self.composition.to_dict, "energy": self.energy}
         return d
 
-    @property
-    def energy(self):
-        """
-        Return final energy
-        """
-        return self._energy
-
     @property
     def energy_per_atom(self):
         """
         Return final energy per atom
         """
-        return self._energy / self.composition.num_atoms
-
-    @property
-    def composition(self):
-        """
-        Returns the composition
-        """
-        return self._composition
+        return self.energy / self.composition.num_atoms
 
     def __repr__(self):
         return "IonEntry : {} with energy = {:.4f}".format(self.composition,
@@ -460,7 +354,6 @@ class PourbaixEntryIO(object):
             latexify_names: Format entry names to be LaTex compatible, e.g.,
                 Li_{2}O
         """
-        import csv
         elements = set()
         map(elements.update, [entry.entry.composition.elements
                               for entry in entries])
@@ -498,7 +391,6 @@ class PourbaixEntryIO(object):
         Returns:
             List of Entries
         """
-        import csv
         reader = csv.reader(open(filename, "rb"), delimiter=",",
                             quotechar="\"", quoting=csv.QUOTE_MINIMAL)
         entries = list()
@@ -519,8 +411,8 @@ class PourbaixEntryIO(object):
                 if phase_type == "Ion":
                     PoE = PourbaixEntry(IonEntry(Ion.from_formula(name),
                                                  energy))
-                    PoE.set_conc(conc)
-                    PoE.set_name(name)
+                    PoE.conc = conc
+                    PoE.name = name
                     entries.append(PoE)
                 else:
                     entries.append(PourbaixEntry(PDEntry(Composition(comp),
@@ -545,7 +437,7 @@ def ion_or_solid_comp_object(formula):
     if m:
         comp_obj = Ion.from_formula(formula)
     elif re.search(r"\(s\)", formula):
-        comp_obj = Composition.from_formula(formula[:-3])
+        comp_obj = Composition(formula[:-3])
     else:
-        comp_obj = Composition.from_formula(formula)
+        comp_obj = Composition(formula)
     return comp_obj
