@@ -54,6 +54,48 @@ def in_coord_list(coord_list, coord, atol=1e-8):
     return len(find_in_coord_list(coord_list, coord, atol=atol)) > 0
 
 
+def is_coord_subset(subset, superset, atol=1e-8):
+    """
+    Tests if all coords in subset are contained in superset.
+    Doesn't use periodic boundary conditions
+    
+    Args:
+        subset, superset: List of coords
+        
+    Returns:
+        True if all of subset is in superset.
+    """
+    c1 = np.array(subset)
+    c2 = np.array(superset)
+    is_close = np.all(np.abs(c1[:, None, :] - c2[None, :, :]) < atol, axis=-1)
+    any_close = np.any(is_close, axis=-1)
+    return np.all(any_close)
+
+
+def coord_list_mapping(subset, superset):
+    """
+    Gives the index mapping from a subset to a superset.
+    Subset and superset cannot contain duplicate rows
+    
+    Args:
+        subset, superset: List of coords
+        
+    Returns:
+        list of indices such that superset[indices] = subset
+    """
+    c1 = np.array(subset)
+    c2 = np.array(superset)
+    inds = np.where(np.all(np.isclose(c1[:, None, :], c2[None, :, :]), axis = 2))[1]
+    result = c2[inds]
+    if not np.allclose(c1, result):
+        if not is_coord_subset(subset, superset):
+            raise ValueError("subset is not a subset of superset")
+    if not result.shape == c1.shape:
+        raise ValueError("Something wrong with the inputs, likely duplicates in "
+                         "superset")
+    return inds
+
+
 def get_linear_interpolated_value(x_values, y_values, x):
     """
     Returns an interpolated value by linear interpolation between two values.
@@ -82,6 +124,24 @@ def get_linear_interpolated_value(x_values, y_values, x):
     return y1 + (y2 - y1) / (x2 - x1) * (x - x1)
 
 
+def all_distances(coords1, coords2):
+    """
+    Returns the distances between two lists of coordinates 
+
+    Args:
+        coords1: First set of cartesian coordinates. 
+        coords2: Second set of cartesian coordinates.
+
+    Returns:
+        2d array of cartesian distances. E.g the distance between
+        coords1[i] and coords2[j] is distances[i,j]
+    """
+    c1 = np.array(coords1)
+    c2 = np.array(coords2)
+    z = (c1[:, None, :] - c2[None, :, :]) ** 2
+    return np.sum(z, axis=-1) ** 0.5
+
+
 def pbc_diff(fcoords1, fcoords2):
     """
     Returns the 'fractional distance' between two coordinates taking into
@@ -300,6 +360,38 @@ def get_points_in_sphere_pbc(lattice, frac_points, center, r):
     return np.transpose(d)
 
 
+def lattice_points_in_supercell(supercell_matrix):
+    """
+    Returns the list of points on the original lattice contained in the supercell
+    in fractional coordinates (with the supercell basis).
+    e.g. [[2,0,0],[0,1,0],[0,0,1]] returns [[0,0,0],[0.5,0,0]] 
+    
+    Args:
+        supercell_matrix: 3x3 matrix describing the supercell
+        
+    Returns:
+        numpy array of the fractional coordinates
+    """
+    diagonals = np.array([[0,0,0],[0,0,1],[0,1,0],[0,1,1],[1,0,0],[1,0,1],[1,1,0],[1,1,1]])
+    d_points = np.dot(diagonals, supercell_matrix)
+    
+    minimax = np.array([np.min(d_points, axis = 0), np.max(d_points, axis = 0) + 1])
+    
+    ar = np.arange(minimax[0, 0], minimax[1, 0])[:, None] * np.array([1, 0, 0])[None, :]
+    br = np.arange(minimax[0, 1], minimax[1, 1])[:, None] * np.array([0, 1, 0])[None, :]
+    cr = np.arange(minimax[0, 2], minimax[1, 2])[:, None] * np.array([0, 0, 1])[None, :]
+    
+    all_points = ar[:, None, None] + br[None, :, None] + cr[None, None, :]
+    all_points = all_points.reshape((-1, 3))
+    
+    frac_points = np.dot(all_points, np.linalg.inv(supercell_matrix))
+    
+    tvects = frac_points[np.where(np.all(frac_points < 1-1e-10, axis=1)
+                            & np.all(frac_points >= -1e-10, axis=1))]
+    assert len(tvects) == np.round(np.abs(np.linalg.det(supercell_matrix)))
+    return tvects
+
+
 def barycentric_coords(coords, simplex):
     """
     Converts a list of coordinates to barycentric coordinates, given a
